@@ -26,6 +26,33 @@ import plotext as plt
 import pint_pandas
 
 class HealthLogUi:
+	def edit_hlid(self):
+		with Session(ENGINE) as session:
+			hlid=Prompt.__init2__(None,func=FormBuilderMkText,ptext="HLID to Edit?: ",helpText="what healthlod id do you wish to edit?",data="integer")
+			if hlid is None:
+				return
+			elif hlid in ['d',]:
+				return
+			else:
+				hl=session.query(HealthLog).filter(HealthLog.HLID==hlid).first()
+				if hl:
+					print(std_colorize(f"Updated {hl}",0,1))
+					excludes=['HLID',]
+					fields={
+						i.name:{
+							'default':getattr(hl,i.name),
+							'type':str(i.type).lower(),
+						} for i in hl.__table__.columns if i.name not in excludes
+					}
+					fd=FormBuilder(data=fields)
+					if fd is None:
+						return
+					for k in fd:
+						setattr(hl,k,fd[k])
+					session.commit()
+					session.refresh(hl)
+					print(std_colorize(f"Updated {hl}",0,1))
+
 	def new_health_log(self):
 		with Session(ENGINE) as session:
 			hl=HealthLog()
@@ -417,12 +444,35 @@ class HealthLogUi:
 
 	def showAllField(self,fields=[],not_none=[]):
 		try:
+			useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
+			if useDateRange is None:
+				return
+			elif useDateRange in ['d',]:
+				useDateRange=True
+
 			gf=fields
 			fields.extend(["DTOE","HLID","Comments"])
 			fields=[i for i in HealthLog.__table__.columns if str(i.name) in fields]
 			not_none=[i for i in HealthLog.__table__.columns if str(i.name) in not_none]
 			with Session(ENGINE) as session:
 				results=session.query(HealthLog).filter(or_(*[i!=None for i in not_none]))
+				if useDateRange:
+					default_sd=datetime.now()-timedelta(days=30)
+					start_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"Start Date(default = {default_sd}):",helpText="start date",data="datetime")
+					if start_date is None:
+						return
+					elif start_date in ['d',]:
+						start_date=default_sd
+
+					default_ed=datetime.now()
+					end_date=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"End Date(default = {default_ed}):",helpText="end date",data="datetime")
+					if end_date is None:
+						return
+					elif end_date in ['d',]:
+						end_date=default_ed
+
+					results=results.filter(and_(HealthLog.DTOE>=start_date,HealthLog.DTOE<=end_date))
+
 				results=orderQuery(results,HealthLog.DTOE)
 				
 				graph_it=Prompt.__init2__(None,func=FormBuilderMkText,ptext="Graph Results (if possible)[y/N]:",helpText="yes or no; default is No.",data="boolean")
@@ -560,6 +610,22 @@ class HealthLogUi:
 			'desc':'list long acting insulin intake',
 			'exec':lambda self=self:self.showAllField(fields=['LongActingInsulinName','LongActingInsulinTaken','LongActingInsulinUnitName'],not_none=['LongActingInsulinTaken',])
 			},
+			uuid1():{
+			'cmds':generate_cmds(startcmd=['edit','ed'],endCmd=['hl','hlid',' ','']),
+			'desc':'edit health log by hlid',
+			'exec':self.edit_hlid,
+			},
+			uuid1():{
+			'cmds':generate_cmds(startcmd=['ls','list','l'],endCmd=['cmts','cmt','comments','comment',' ','']),
+			'desc':'ls only comments',
+			'exec':lambda self=self:self.showAllField(fields=['Comments',],not_none=['Comments',])
+			},
+			uuid1():{
+			'cmds':generate_cmds(startcmd=['a','add','+'],endCmd=['cmts','cmt','comments','comment',' ','']),
+			'desc':'add a comment to the log',
+			'exec':lambda self=self:self.add_healthlog_specific(
+					useColumns=["Comments",])
+			},
 			'ls sai':{
 			'cmds':['ls sai','lssai','list short insulin','list short acting insulin'],
 			'desc':'list long acting insulin intake',
